pub trait GithubApi: Send + Sync {
// Required methods
fn get_pr_status<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
owner: &'life1 str,
repo: &'life2 str,
pr_number: u64,
) -> Pin<Box<dyn Future<Output = Result<PrStatus>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn get_ci_checks<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
owner: &'life1 str,
repo: &'life2 str,
head_sha: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<CheckRun>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
fn get_review_threads<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
owner: &'life1 str,
repo: &'life2 str,
pr_number: u64,
) -> Pin<Box<dyn Future<Output = Result<Vec<ReviewThread>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn find_open_pr_for_branch<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
owner: &'life1 str,
repo: &'life2 str,
branch: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<Option<PrRef>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
}Required Methods
fn get_pr_status<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
owner: &'life1 str,
repo: &'life2 str,
pr_number: u64,
) -> Pin<Box<dyn Future<Output = Result<PrStatus>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn get_ci_checks<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
owner: &'life1 str,
repo: &'life2 str,
head_sha: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<Vec<CheckRun>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn get_review_threads<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
owner: &'life1 str,
repo: &'life2 str,
pr_number: u64,
) -> Pin<Box<dyn Future<Output = Result<Vec<ReviewThread>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Sourcefn find_open_pr_for_branch<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
owner: &'life1 str,
repo: &'life2 str,
branch: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<Option<PrRef>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn find_open_pr_for_branch<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
owner: &'life1 str,
repo: &'life2 str,
branch: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<Option<PrRef>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Find an open PR whose head branch is branch, independent of any
metadata the gh wrapper hook may or may not have recorded — the
active fallback for PRs created outside the wrapped gh pr create.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".